Added alpha, and sha1 string types to random_string() in the String Helper.
diff --git a/system/helpers/string_helper.php b/system/helpers/string_helper.php
index 67cbd0e..4767f0b 100644
--- a/system/helpers/string_helper.php
+++ b/system/helpers/string_helper.php
@@ -186,22 +186,27 @@
  * Useful for generating passwords or hashes.
  *
  * @access	public
  * @param	string 	type of random string.  Options: alunum, numeric, nozero, unique
  * @param	integer	number of characters
  * @return	string
- */
+ */	
 if ( ! function_exists('random_string'))
-{	
+{
 	function random_string($type = 'alnum', $len = 8)
 	{					
 		switch($type)
 		{
+			case 'basic'	: return mt_rand();
+			  break;
 			case 'alnum'	:
 			case 'numeric'	:
 			case 'nozero'	:
+			case 'alpha'	:
 		
 					switch ($type)
 					{
+						case 'alpha'	:	$pool = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
+							break;
 						case 'alnum'	:	$pool = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
 							break;
 						case 'numeric'	:	$pool = '0123456789';
@@ -217,12 +222,22 @@
 					}
 					return $str;
 			  break;
-			case 'unique' : return md5(uniqid(mt_rand()));
+			case 'unique'	: 
+			case 'md5' 		: 
+				
+						return md5(uniqid(mt_rand()));
+			  break;
+			case 'encrypt'	: 
+			case 'sha1'	: 
+		
+						$CI =& get_instance();
+						$CI->load->helper('security');
+		
+						return do_hash(uniqid(mt_rand(), TRUE), 'sha1');
 			  break;
 		}
 	}
 }
-
 // ------------------------------------------------------------------------
 
 /**
@@ -186,22 +186,27 @@
  *
  * @access	public
- * @param	string 	type of random string.  Options: alunum, numeric, nozero, unique
+ * @param	string 	type of random string.  basic, alpha, alunum, numeric, nozero, unique, md5, encrypt and sha1
  * @param	integer	number of characters
  * @return	string